@@ -42,4 +42,7 @@ def ditto(dir, dataset, batch_size, num_nodes, model, objective, optimizer, glob
             nodes[j].local_test(device)
         # server aggregation and distribution
         server.aggregate(nodes, list(range(num_nodes)), device)
-        # server.distribute(nodes, list(range(num_nodes)))
\ No newline at end of file
+        # server.distribute(nodes, list(range(num_nodes)))
+
+    # log
+    log(os.path.basename(__file__)[:-3], nodes, server)
\ No newline at end of file
