@@ -11,6 +11,7 @@ import os
 import pickle
 import datetime as d
 import math
+import pandas as pd
 
 
 class data_process:
@@ -20,31 +21,31 @@ class data_process:
                 transforms.ToTensor(),
                 transforms.Normalize((0.1307,), (0.3081,))])
             self.train_dataset = datasets.MNIST(
-                dir, train=True, download=True, transform=apply_transform)
+                dir+dataset_name, train=True, download=True, transform=apply_transform)
             self.test_dataset = datasets.MNIST(
-                dir, train=False, download=True, transform=apply_transform)
+                dir+dataset_name, train=False, download=True, transform=apply_transform)
         elif dataset_name == 'cifar10':
             transform = transforms.Compose(
                 [transforms.ToTensor(), transforms.Normalize((0.5, 0.5, 0.5), (0.5, 0.5, 0.5))])
             self.train_dataset = datasets.CIFAR10(
-                dir, train=True, download=True, transform=transform)
+                dir+dataset_name, train=True, download=True, transform=transform)
             self.test_dataset = datasets.CIFAR10(
-                dir, train=False, download=True, transform=transform)
+                dir+dataset_name, train=False, download=True, transform=transform)
         elif dataset_name == 'femnist':
             apply_transform = transforms.Compose(
                 [transforms.ToTensor(), transforms.Normalize((0.1307,), (0.3081,))])
-            train_dataset = femnist.FEMNIST(dir, train=True, download=False,
+            train_dataset = femnist.FEMNIST(dir+dataset_name, train=True, download=False,
                                             transform=apply_transform)
-            test_dataset = femnist.FEMNIST(dir, train=False, download=False,
+            test_dataset = femnist.FEMNIST(dir+dataset_name, train=False, download=False,
                                            transform=apply_transform)
         elif dataset_name == 'Fashion_Mnist':
             apply_transform = transforms.Compose([
                 transforms.ToTensor(),
                 transforms.Normalize((0.5,), (0.5,))])
             self.train_dataset = datasets.FashionMNIST(
-                dir, train=True, download=True, transform=apply_transform)
+                dir+dataset_name, train=True, download=True, transform=apply_transform)
             self.test_dataset = datasets.FashionMNIST(
-                dir, train=False, download=True, transform=apply_transform)
+                dir+dataset_name, train=False, download=True, transform=apply_transform)
 
         # show image
         # batch_size = 4
@@ -98,21 +99,12 @@ class data_process:
                         J = np.random.choice(len(labels), alpha, replace=False)
                         x[J] = 1
                         p = np.concatenate((p, x), axis=1)
-                    p = p / \
-                        np.repeat(
-                            (p.sum(axis=1)+10**-10).reshape(len(labels), 1), num_nodes, axis=1)
+                    p = p / np.repeat((p.sum(axis=1)+10**-10).reshape(len(labels), 1), num_nodes, axis=1)
                 # print(p.sum(axis=1),p)
-                # p = torch.tensor(np.random.dirichlet(np.repeat(alpha,len(labels)), num_nodes)).reshape(10,100)
-                # for i in range(len(p)):
-                #     if l_test*p[i]<10:
-                #         p[i]+=0.01
-                #         p[p==p.max()]-=0.01
                 train_size = torch.round(l_train*p).int()
                 # train_size = train_size.int()
                 test_size = torch.round(l_test*p).int()
                 # test_size = test_size.int()
-                # print(torch.sum(train_size,0),torch.sum(test_size,0))
-                # print(len((self.train_dataset.targets==0).nonzero(as_tuple=True)[0]))
                 train_splited = []
                 test_splited = []
                 train_label_index = []
@@ -145,6 +137,23 @@ class data_process:
                 return train_splited, test_splited
 
 
+def log(file_name, nodes, server):
+    local_file = ".\log\\" + file_name + "_" + d.datetime.now().strftime("%Y%m%d%H%M%S") + ".pkl"
+    log = {}
+    log['node'] = {}
+    for i in range(len(nodes)):
+        log['node'][str(i)] = nodes[i].accuracy
+    log['server'] = server.accuracy
+    log['clustering'] = server.clustering
+    # pd.to_pickle(log, local_file)
+    with  open(local_file, 'wb') as handle:
+        pickle.dump(log, handle, protocol=pickle.HIGHEST_PROTOCOL)
+
+    # read
+    if os.path.exists(local_file):
+        log = pickle.load(open(local_file, 'rb'))
+        print(log)
+
 # dt = data_process('mnist')
 # # dt.split_dataset(50, 2, method='class')
 # dt.split_dataset(10, 0.1)
@@ -180,17 +189,4 @@ class data_process:
 #         return image, label
 
 
-def log(file_name, nodes, server):
-    local_file = './log/' + file_name + '_' + str(d.datetime.now()) + '.pkl'
-    log = {}
-    log['node'] = {}
-    for i in range(len(nodes)):
-        log['node'][str(i)] = nodes[i].accuracy
-    log['server'] = server.accuracy
-    log['clustering'] = server.clustering
-    pickle.dump(log, open(local_file, 'wb'), protocol=pickle.HIGHEST_PROTOCOL)
 
-    # read
-    if os.path.exists(local_file):
-        log = pickle.load(open(local_file, 'rb'))
-        print(log)
